package br.ufrn.imd.authenticator.service;

import br.ufrn.imd.authenticator.domain.Client;
import br.ufrn.imd.authenticator.exception.BadRequestException;
import br.ufrn.imd.authenticator.repository.ClientRepository;
import lombok.RequiredArgsConstructor;
import lombok.extern.java.Log;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.stereotype.Service;

import javax.security.auth.message.AuthException;

@Log
@RequiredArgsConstructor
@Service
public class AuthenticatorService {
    private final ClientRepository clientRepository;

    public Client authenticate(String accountNumber, String password) {
        Client client = clientRepository.findByAccountNumber(accountNumber)
                .orElseThrow(() -> new BadRequestException(
                        String.format("Customer not found with account number %s", accountNumber)));

        if(!new BCryptPasswordEncoder().matches(password, client.getAccount().getPassword())) {
            throw new BadRequestException("Bad credentials");
        }

        log.info(client.getName() + " logged in (account number: " + client.getAccount().getNumber() + ")");
        return client;
    }
}
